=======
History
=======

0.1.1 (2021-10-02)
------------------
* Adjust URLs to GitHub account due to renaming @munterfinger to @munterfi.
* Note: zeitsprung.fm has moved to geschichte.fm, therefore this project no longer is maintained.

0.1.0 (2020-09-22)
------------------

* First release on PyPI.
* Scraper class to download the meta data and audio files of all episodes.
* Database class to setup and access the SQLite database containing the meta data of the episodes.
* Documentation using readthedocs: https://zeitsprung.readthedocs.io/en/latest/
* Github action for building and testing the package.
* Coverage tests using codecov.io.
